@@ -97,6 +97,7 @@ DEFAULTS = {'apiurl': 'https://api.opensuse.org',
             'build-swap': '',                   # optional for VM builds
             'build-vmdisk-rootsize': '',        # optional for VM builds
             'build-vmdisk-swapsize': '',        # optional for VM builds
+            'build-vmdisk-filesystem': '',        # optional for VM builds
 
             'build-jobs': _get_processors(),
             'builtin_signature_check': '1',     # by default use builtin check for verify pkgs
@@ -141,6 +142,9 @@ DEFAULTS = {'apiurl': 'https://api.opensuse.org',
             # what to do with the source package if the submitrequest has been accepted
             'submitrequest_on_accept_action': '',
             'request_show_interactive': '0',
+            # if a review is accepted in interactive mode and a group
+            # was specified the review will be accepted for this group
+            'review_inherit_group': '0',
             'submitrequest_accepted_template': '',
             'submitrequest_declined_template': '',
             'linkcontrol': '0',
@@ -160,8 +164,8 @@ config = DEFAULTS.copy()
 
 boolean_opts = ['debug', 'do_package_tracking', 'http_debug', 'post_mortem', 'traceback', 'check_filelist', 'plaintext_passwd',
     'checkout_no_colon', 'checkout_rooted', 'check_for_request_on_action', 'linkcontrol', 'show_download_progress', 'request_show_interactive',
-    'use_keyring', 'gnome_keyring', 'no_verify', 'builtin_signature_check', 'http_full_debug', 'include_request_from_project',
-    'local_service_run']
+    'review_inherit_group', 'use_keyring', 'gnome_keyring', 'no_verify', 'builtin_signature_check', 'http_full_debug',
+    'include_request_from_project', 'local_service_run']
 
 api_host_options = ['user', 'pass', 'passx', 'aliases', 'http_headers', 'email', 'sslcertck', 'cafile', 'capath', 'trusted_prj']
 
@@ -217,6 +221,10 @@ apiurl = %(apiurl)s
 # values in MB - e.g. 1024
 #build-vmdisk-swapsize = 1024
 
+# build-vmdisk-filesystem is the file system type of the disk-image used in a VM build
+# values are ext3(default) ext4 xfs reiserfs btrfs
+#build-vmdisk-filesystem = ext4
+
 # Numeric uid:gid to assign to the "abuild" user in the build-root
 # or "caller" to use the current users uid:gid
 # This is convenient when sharing the buildroot with ordinary userids
@@ -300,6 +308,10 @@ apiurl = %(apiurl)s
 #review requests interactively (default: off)
 #request_show_review = 1
 
+# if a review is accepted in interactive mode and a group
+# was specified the review will be accepted for this group (default: off)
+#review_inherit_group = 1
+
 [%(apiurl)s]
 user = %(user)s
 pass = %(pass)s
@@ -791,8 +803,14 @@ def get_config(override_conffile=None,
             # Read from gnome keyring if available
             try:
                 gk_data = gnomekeyring.find_network_password_sync(protocol=scheme, server=host)
-                password = gk_data[0]['password']
+                if not 'user' in gk_data[0]:
+                    raise oscerr.ConfigError('no user found in keyring', conffile)
                 user = gk_data[0]['user']
+                if 'password' in gk_data[0]:
+                    password = gk_data[0]['password']
+                else:
+                    # this is most likely an error
+                    print >>sys.stderr, 'warning: no password found in keyring'
             except gnomekeyring.NoMatchError:
                 # Fallback to file based auth.
                 pass
@@ -817,7 +835,7 @@ def get_config(override_conffile=None,
                 password = ''
 
             if user is None or user == '':
-                raise oscerr.ConfigError('user is blank for %s, please delete of complete the "user=" entry in %s.' % (apiurl, config['conffile']), config['conffile'])
+                raise oscerr.ConfigError('user is blank for %s, please delete or complete the "user=" entry in %s.' % (apiurl, config['conffile']), config['conffile'])
 
             if config['plaintext_passwd'] and passwordx or not config['plaintext_passwd'] and password:
                 if config['plaintext_passwd']:
@@ -878,7 +896,7 @@ def get_config(override_conffile=None,
     apiurl = aliases.get(config['apiurl'], config['apiurl'])
     config['apiurl'] = urljoin(*parse_apisrv_url(None, apiurl))
     # backward compatibility
-    if key in config:
+    if 'apisrv' in config:
         apisrv = config['apisrv'].lstrip('http://')
         apisrv = apisrv.lstrip('https://')
         scheme = config.get('scheme', 'https')
