@@ -12,6 +12,7 @@ from util import packagequery, cpio
 import conf
 import oscerr
 import tempfile
+import re
 try:
     from meter import TextMeter
 except:
@@ -112,7 +113,8 @@ class Fetcher:
                         archive.copyin_file(hdr.filename)
                         raise oscerr.APIError('CPIO archive is incomplete (see .errors file)')
                     if package == '_repository':
-                        pac = pkgs[hdr.filename.rsplit('.', 1)[0]]
+                        n = re.sub(r'\.pkg\.tar\..z$', '.arch', hdr.filename)
+                        pac = pkgs[n.rsplit('.', 1)[0]]
                     else:
                         # this is a kiwi product
                         pac = pkgs[hdr.filename]
@@ -165,7 +167,14 @@ class Fetcher:
     def move_package(self, tmpfile, destdir, pac_obj = None):
         import shutil
         pkgq = packagequery.PackageQuery.query(tmpfile, extra_rpmtags=(1044, 1051, 1052))
-        canonname = pkgq.canonname()
+        if pkgq:
+          canonname = pkgq.canonname()
+        else:
+          if pac_obj is None:
+            print >>sys.stderr, 'Unsupported file type: ', tmpfile
+            sys.exit(1)
+          canonname = pac_obj.binary
+
         fullfilename = os.path.join(destdir, canonname)
         if pac_obj is not None:
             pac_obj.filename = canonname
